==> uberfire-parent-2.3.0.Final-project-sources.tar.gz: uberfire-parent-2.3.0.Final/README.md <==
[![Uberfire](http://uberfireframework.org/upload/images/uberfire-logo.png)](http://uberfireframework.org/)

[![Build Status](http://ci.kiegroup.org/buildStatus/icon?job=uberfire)](http://ci.kiegroup.org/job/uberfire)

Uberfire is a web framework for a superior experience in building extensible workbenches and console type applications.
It provides an Eclipse like workbench experience for the web, helping you to make maintainable, customizable workbench-style apps in no time flat.

Our ultimate goal in Uberfire is to provide a strong ecosystem around it, based on a rich set of pluggable components and a strong infrastructure, allowing different type of users easily build Rich Web Apps on top of it.

Uberfire is the technology behind of Drools and jBPM web tooling, and is based on challenges and lessons learned during the workbench development of these projects.

## Learning about Uberfire

For those who prefer hands-on learning, checkout the [Uberfire Tutorial](http://www.uberfireframework.org/docs/tutorial/tutorial.html) to create a working Uberfire application, or learn how to start your own project with our [Getting Started Guide](http://www.uberfireframework.org/docs/gettingStarted/gettingStarted.html).

And for those who prefer the top-down approach, you can find a detailed descriptions of how to use Uberfire in our [documentation](http://www.uberfireframework.org/docs/index.html).

## Uberfire Community Support

Visit our IRC channel (#appformer on freenode) to hang out and share solutions with the Uberfire community.

## Contributing to Uberfire

Report bugs or request features through our [issue tracker](https://issues.jboss.org/projects/UF).

Contribute code through pull requests to this repository. See our [contributing guidelines](https://github.com/droolsjbpm/droolsjbpm-build-bootstrap/blob/master/README.md) for more details.

## Building and contributing to our documentation

In order to build and contribute to our documentation, follow this steps
   
- Fork the repository https://github.com/uberfire/uberfire then clone the fork locally
- Get gitbook editor from https://github.com/GitbookIO/editor-legacy
- Get gitbook builder from https://github.com/GitbookIO/gitbook (you may need to install npm first)
- Edit the docs in your forked repository ../uberfire/uberfire-docs in gitbook editor
- When you've finished editing, build the docs by running uberfire-docs/buildHtml.sh and uberfire-docs/buildPdf.sh
- View the built docs in uberfire-docs/docs/_book/index.html and uberfire-docs/uberfire-docs.pdf
- Submit a pull request to get your changes accepted

## License

Uberfire Framework is released under Apache 2 License.

Check [LICENSE](https://github.com/uberfire/uberfire/blob/master/LICENSE-ASL-2.0.txt) file for more information.

==> uberfire-parent-7.52.0.Final-project-sources.tar.gz: uberfire-parent-7.52.0.Final/README.md <==
[![Uberfire](http://uberfireframework.org/upload/images/uberfire-logo.png)](http://uberfireframework.org/)

[![Build Status](http://ci.kiegroup.org/buildStatus/icon?job=uberfire)](http://ci.kiegroup.org/job/uberfire)

Uberfire is a web framework for a superior experience in building extensible workbenches and console type applications.
It provides an Eclipse like workbench experience for the web, helping you to make maintainable, customizable workbench-style apps in no time flat.

Our ultimate goal in Uberfire is to provide a strong ecosystem around it, based on a rich set of pluggable components and a strong infrastructure, allowing different type of users easily build Rich Web Apps on top of it.

Uberfire is the technology behind of Drools and jBPM web tooling, and is based on challenges and lessons learned during the workbench development of these projects.

## Learning about Uberfire

For those who prefer hands-on learning, checkout the [Uberfire Tutorial](http://www.uberfireframework.org/docs/tutorial/tutorial.html) to create a working Uberfire application, or learn how to start your own project with our [Getting Started Guide](http://www.uberfireframework.org/docs/gettingStarted/gettingStarted.html).

And for those who prefer the top-down approach, you can find a detailed descriptions of how to use Uberfire in our [documentation](http://www.uberfireframework.org/docs/index.html).

## Uberfire Community Support

Visit our IRC channel (#appformer on freenode) to hang out and share solutions with the Uberfire community.

## Contributing to Uberfire

Report bugs or request features through our [issue tracker](https://issues.jboss.org/projects/UF).

Contribute code through pull requests to this repository. See our [contributing guidelines](https://github.com/droolsjbpm/droolsjbpm-build-bootstrap/blob/master/README.md) for more details.

## Building and contributing to our documentation

In order to build and contribute to our documentation, follow this steps

- Fork the repository https://github.com/kiegroup/appformer then clone the fork locally
- Get gitbook editor from https://github.com/GitbookIO/editor-legacy
- Get gitbook builder from https://github.com/GitbookIO/gitbook (you may need to install npm first)
- Edit the docs in your forked repository ../appformer/uberfire-docs in gitbook editor
- When you've finished editing, build the docs by running uberfire-docs/buildHtml.sh and uberfire-docs/buildPdf.sh
- View the built docs in uberfire-docs/docs/_book/index.html and uberfire-docs/uberfire-docs.pdf
- Submit a pull request to get your changes accepted

## License

Uberfire Framework is released under Apache 2 License.

Check [LICENSE](LICENSE-ASL-2.0.txt) file for more information.
